@@ -85,6 +85,20 @@ echo $array | sed "s/ /<\/file>\n<file>/g" >> screencast.qrc
 array="<file>"$( find ./sound/* -name *.wav | cut -c 3- )"</file>"
 echo $array | sed "s/ /<\/file>\n<file>/g" >> screencast.qrc
 
+###############################
+# cisco openh264 binary license
+###############################
+array="<file>"$( find ./ciscoOpenh264/* -name *.txt | cut -c 3- )"</file>"
+echo $array | sed "s/ /<\/file>\n<file>/g" >> screencast.qrc
+
+###############################
+# spezialCheckBox
+###############################
+array="<file>"$( find ./spezialCheckBox/* -name *.png | cut -c 3- )"</file>"
+echo $array | sed "s/ /<\/file>\n<file>/g" >> screencast.qrc
+array="<file>"$( find ./spezialCheckBox/* -name *.license | cut -c 3- )"</file>"
+echo $array | sed "s/ /<\/file>\n<file>/g" >> screencast.qrc
+
 ################
 # language packs
 ################
