@@ -23,6 +23,7 @@
 #include "QvkCameraController.h"
 #include "QvkCameraResolution.h"
 #include "global.h"
+#include "camerasettingsdialog.h"
 
 #include <QCameraInfo>
 
@@ -40,12 +41,15 @@ QvkCameraController::QvkCameraController( Ui_formMainWindow *ui_surface ):videoS
     sliderCameraWindowSize->setShowValue( false );
     sliderCameraWindowSize->setEnabled( false );
 
-    QvkCameraResolution *vkCameraResolution = new QvkCameraResolution( ui_formMainWindow );
+    vkCameraSettingsDialog = new cameraSettingsDialog;
+
+    QvkCameraResolution *vkCameraResolution = new QvkCameraResolution( ui_formMainWindow, vkCameraSettingsDialog );
     connect( ui_formMainWindow->comboBoxCamera, SIGNAL( currentIndexChanged( int ) ), vkCameraResolution, SLOT( slot_resolution( int ) ) );
+    connect( ui_formMainWindow->comboBoxCameraResolution, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_resolutionChanged() ) );
 
     getAllDevices();
 
-    cameraWindow = new QvkCameraWindow( ui_surface, sliderCameraWindowSize );
+    cameraWindow = new QvkCameraWindow( ui_surface, sliderCameraWindowSize, vkCameraSettingsDialog );
     cameraWindow->hide();
     connect( cameraWindow, SIGNAL( signal_cameraWindow_close( bool ) ), ui_formMainWindow->checkBoxCameraOnOff, SLOT( setChecked( bool ) ) );
     cameraWindow->setWindowTitle( QString( tr( "Camera") ) );
@@ -59,15 +63,13 @@ QvkCameraController::QvkCameraController( Ui_formMainWindow *ui_surface ):videoS
 
     connect( ui_formMainWindow->checkBoxCameraOnOff, SIGNAL( toggled( bool ) ), ui_formMainWindow->comboBoxCamera, SLOT( setDisabled( bool ) ) );
     connect( ui_formMainWindow->checkBoxCameraOnOff, SIGNAL( toggled( bool ) ), this, SLOT( slot_startCamera( bool ) ) );
-    connect( ui_formMainWindow->checkBoxCameraOnOff, SIGNAL( toggled( bool ) ), ui_formMainWindow->checkBoxCameraWindowFrame, SLOT( setEnabled(bool ) ) );
-    connect( ui_formMainWindow->checkBoxCameraOnOff, SIGNAL( toggled( bool ) ), ui_formMainWindow->comboBoxCameraResolution, SLOT( setDisabled(bool ) ) );
+    connect( ui_formMainWindow->checkBoxCameraOnOff, SIGNAL( toggled( bool ) ), ui_formMainWindow->checkBoxCameraWindowFrame, SLOT( setEnabled( bool ) ) );
 
     connect( videoSurface, SIGNAL( signal_newPicture( QImage ) ), this, SLOT( slot_setNewImage( QImage ) ) );
 
     connect( ui_formMainWindow->checkBoxCameraWindowFrame, SIGNAL( toggled( bool ) ), this, SLOT( slot_frameOnOff( bool ) ) );
 
     connect( sliderCameraWindowSize, SIGNAL( valueChanged( int ) ), this, SLOT( slot_sliderMoved( int ) ) );
-
 }
 
 
@@ -76,6 +78,22 @@ QvkCameraController::~QvkCameraController()
 }
 
 
+void QvkCameraController::slot_resolutionChanged()
+{
+    if ( ui_formMainWindow->checkBoxCameraOnOff->checkState() == Qt::Checked )
+    {
+        ui_formMainWindow->checkBoxCameraOnOff->click();
+        ui_formMainWindow->checkBoxCameraOnOff->click();
+
+        if ( vkCameraSettingsDialog->isVisible() == true )
+        {
+            vkCameraSettingsDialog->close();
+            vkCameraSettingsDialog->show();
+        }
+    }
+}
+
+
 void QvkCameraController::getAllDevices()
 {
     QList<QCameraInfo> camerasInfoList = QCameraInfo::availableCameras();
@@ -97,19 +115,38 @@ void QvkCameraController::slot_frameOnOff( bool value )
 {
     if ( cameraWindow->isVisible() == true )
     {
-        Qt::WindowFlags flags = 0;
+        Qt::WindowFlags flags;
 
+#ifdef Q_OS_WIN
         if ( value == true )
         {
-            flags = Qt::Window | Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint;
+            flags = Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint;
             cameraWindow->setWindowFlags( flags );
         }
 
         if ( value == false )
         {
-            flags = Qt::Window | Qt::WindowStaysOnTopHint;
+            flags = Qt::WindowStaysOnTopHint;
             cameraWindow->setWindowFlags( flags );
         }
+#endif
+
+#ifdef Q_OS_LINUX
+        if ( value == true )
+        {
+            vkCameraSettingsDialog->ui->pushButtonSwitchToFullscreen->setDisabled( true );
+            cameraWindow->setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint );
+            ui_formMainWindow->checkBoxCameraOnOff->click();
+            ui_formMainWindow->checkBoxCameraOnOff->click();
+        }
+
+        if ( value == false )
+        {
+            vkCameraSettingsDialog->ui->pushButtonSwitchToFullscreen->setDisabled( false );
+            flags = Qt::WindowStaysOnTopHint;
+            cameraWindow->setWindowFlags( flags );
+        }
+#endif
 
         cameraWindow->show();
     }
@@ -162,7 +199,7 @@ void QvkCameraController::slot_setNewImage( QImage image )
     if ( ui_formMainWindow->checkBoxCameraMono->isChecked() == true )
         image = image.convertToFormat( QImage::Format_Mono );
 
-    image = image.scaled( cameraWindow->width(), cameraWindow->height(), Qt::KeepAspectRatio, Qt::FastTransformation);
+    image = image.scaled( cameraWindow->width(), cameraWindow->height(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
     cameraWindow->setPixmap( QPixmap::fromImage( image, Qt::AutoColor) );
 }
 
@@ -170,8 +207,8 @@ void QvkCameraController::slot_setNewImage( QImage image )
 void QvkCameraController::slot_addedCamera( QString description, QString device )
 {
     ui_formMainWindow->checkBoxCameraOnOff->setEnabled( true );
-    ui_formMainWindow->comboBoxCameraResolution->setEnabled( true );
     ui_formMainWindow->comboBoxCamera->setEnabled( true );
+    ui_formMainWindow->comboBoxCameraResolution->setEnabled( true );
     ui_formMainWindow->comboBoxCamera->addItem( description, device.toLatin1() );
     ui_formMainWindow->checkBoxCameraGray->setEnabled( true );
     ui_formMainWindow->checkBoxCameraInvert->setEnabled( true );
@@ -199,8 +236,8 @@ void QvkCameraController::slot_removedCamera( QString device )
     {
         ui_formMainWindow->checkBoxCameraOnOff->setEnabled( false );
         ui_formMainWindow->comboBoxCamera->setEnabled( false );
-        ui_formMainWindow->comboBoxCameraResolution->setEnabled( false );
         ui_formMainWindow->comboBoxCameraResolution->clear();
+        ui_formMainWindow->comboBoxCameraResolution->setEnabled( false );
         ui_formMainWindow->checkBoxCameraGray->setEnabled( false );
         ui_formMainWindow->checkBoxCameraInvert->setEnabled( false );
         ui_formMainWindow->checkBoxCameraMirrorHorizontal->setEnabled( false );
