@@ -1,6 +1,6 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
- * 
+ * Copyright (C) 2017-2021 Volker Kohaupt
+ *
  * Author:
  *      Volker Kohaupt <vkohaupt@freenet.de>
  *
@@ -25,28 +25,49 @@
 
 #include <QObject>
 
+#include "ui_formMainWindow.h"
+#include "QvkCiscoWaitDialog.h"
+
 class QvkCiscoOpenh264Controller: public QObject
 {
     Q_OBJECT
 
 public:
-    QvkCiscoOpenh264Controller();
+    QvkCiscoOpenh264Controller( QString pathWithSettingsFilename , Ui_formMainWindow *ui_mainwindow );
     virtual ~QvkCiscoOpenh264Controller();
+    void init();
+    bool isShowCiscoFinishDialog = false;
+    void showWaitDialog();
+
 
-    
 public slots:
 
-  
-private:
 
-    
+private:
+    Ui_formMainWindow *ui;
+    QString libopenh264_filename;
+    QString pathWithSettingsFilename;
+    QvkCiscoWaitDialog *vkCiscoWaitDialog;
+    QString downloadFile;
+
+
 private slots:
     void slot_deCompress( QString string );
+    void slot_showCiscoFinishDialog();
+    void slot_pushButtonCiscoLicense();
+    void slot_cisco_on( bool );
+    void slot_cisco_off( bool );
+    void slot_closeWaitDialog();
+
+
+    void slot_downloadProgress( qint64 downloadedSize, qint64 fileSize );
+
 
 protected:
-  
-  
+
+
 signals:
+    void signal_ciscofile_now_downloded( bool );
 
 };
 
