@@ -1,6 +1,6 @@
 /* vokoscreenNG - A desktop recorder
  * Copyright (C) 2017-2019 Volker Kohaupt
- * 
+ *
  * Author:
  *      Volker Kohaupt <vkohaupt@freenet.de>
  *
@@ -24,7 +24,9 @@
 #define QVKCOUNTDOWN_H
 
 #include <QWidget>
-#include <QPainter>
+//#include <QPainter>
+
+#include "QvkCountdownWindow.h"
 
 class QvkCountdown: public QWidget
 {
@@ -32,6 +34,7 @@ class QvkCountdown: public QWidget
 public:
     QvkCountdown();
     virtual ~QvkCountdown();
+    void init();
     void startCountdown(int value );
     int x;
     int y;
@@ -41,28 +44,27 @@ public:
     
 public slots:
 
-  
+
 private:
-    int countValue;
-    int oldCountValue;
-    int gradValue;
+    QvkCountdownWindow *vkCountdownWindow;
+    void createCountdownWindow();
     QTimer *timer;
     QTimer *animationTimer;
-    QPainter painter;
 
-    
+
 private slots:
-   void slot_updateTimer();
-   void slot_updateAnimationTimer();
+    void slot_updateTimer();
+    void slot_updateAnimationTimer();
+    void slot_cancel( bool value );
 
 
 protected:
-    void paintEvent( QPaintEvent *event );
-  
-  
+
+
 signals:
     void signal_countDownfinish( bool value );
     void signal_countdownBegin( bool value );
+    void signal_countDownCancel( bool value);
 
 };
 
