@@ -22,21 +22,18 @@
 
 #include "global.h"
 #include <QString>
-#include <QLineEdit>
 
 namespace global
 {
     QString name = "vokoscreenNG";
     QString nameOutput = "[" + name + "]";
-    bool VK_showOnlyFallbackIcons = true; // From 3.0.5 have windows and linux the same icons
-    QLineEdit *lineEditAudioPlug;
+    int showclickCounter = 0;
 
 #ifdef Q_OS_LINUX
-    QString version = "3.0.7";
-
+    QString version = "3.1.0";
 #endif
 
 #ifdef Q_OS_WIN
-    QString version = "3.0.7";
+    QString version = "3.1.0";
 #endif
 }
