@@ -21,14 +21,11 @@
  */
 
 #include <QString>
-#include <QLineEdit>
 
 namespace global
 {
     extern QString name;
     extern QString nameOutput;
     extern QString version;
-    extern bool VK_showOnlyFallbackIcons;
-    extern QLineEdit *lineEditAudioPlug;
-
+    extern int showclickCounter;
 }
