@@ -44,13 +44,13 @@
  * See also QvkHelp::eventFilter(QObject *object, QEvent *event)
  */
 
-QvkHelp::QvkHelp(QMainWindow *mainWindow, Ui_formMainWindow *ui_mainwindow ) : uiHelp(new(Ui::help))
+QvkHelp::QvkHelp( Ui_formMainWindow *ui_mainwindow ) : uiHelp(new(Ui::help))
 {
-    connect( mainWindow, SIGNAL( destroyed( QObject*) ), this, SLOT( slot_cleanUp() ) );
-
     ui = ui_mainwindow;
     uiHelp->setupUi( this );
 
+    connect(uiHelp->buttonBox, SIGNAL( clicked( QAbstractButton * ) ), this, SLOT( close() ) );
+
     slot_NetworkAccessibility( networkAccessManager.networkAccessible() );
     connect( &networkAccessManager, SIGNAL( networkAccessibleChanged( QNetworkAccessManager::NetworkAccessibility ) ),
                                     SLOT( slot_NetworkAccessibility( QNetworkAccessManager::NetworkAccessibility ) ) );
@@ -130,6 +130,16 @@ void QvkHelp::slot_NetworkAccessibility( QNetworkAccessManager::NetworkAccessibi
             }
         }
     }
+
+    if ( accessible == QNetworkAccessManager::Accessible )
+    {
+        ui->comboBoxOnlineHelp->setEnabled( true );
+    }
+
+    if ( accessible == QNetworkAccessManager::NotAccessible )
+    {
+        ui->comboBoxOnlineHelp->setEnabled( false );
+    }
 }
 
 
