@@ -29,8 +29,12 @@
 #include <QMessageBox>
 #include <QDebug>
 
-QvkInformation::QvkInformation( QMainWindow *mainWindow, Ui_formMainWindow *ui_mainwindow, QvkSpezialSlider *slider_count_down, QvkSpezialSlider *slider_Second_Wait_Before_Recording )
+QvkInformation::QvkInformation( QvkMainWindow *vkMainWindow,
+                                Ui_formMainWindow *ui_mainwindow,
+                                QvkSpezialSlider *slider_count_down,
+                                QvkSpezialSlider *slider_Second_Wait_Before_Recording )
 {
+    mainWindow = vkMainWindow;
     ui = ui_mainwindow;
     sliderCountDown = slider_count_down;
     sliderSecondWaitBeforeRecording = slider_Second_Wait_Before_Recording;
@@ -49,7 +53,7 @@ QvkInformation::QvkInformation( QMainWindow *mainWindow, Ui_formMainWindow *ui_m
     timerStorageInfo->start();
 
     // Recorded time
-    elapsedTime = new QTime( 0, 0, 0, 0 );
+    elapsedTime = new QElapsedTimer();
     connect( ui->pushButtonStart,    SIGNAL( clicked( bool ) ), this, SLOT( slot_timeFirstStart() ) );
     connect( ui->pushButtonPause,    SIGNAL( clicked( bool ) ), this, SLOT( slot_summedTimeAfterPause() ) );
     connect( ui->pushButtonContinue, SIGNAL( clicked( bool ) ), this, SLOT( slot_timeContinueStart() ) );
@@ -63,10 +67,18 @@ QvkInformation::QvkInformation( QMainWindow *mainWindow, Ui_formMainWindow *ui_m
     connect( ui->pushButtonPause,    SIGNAL( clicked( bool ) ), timerRecord, SLOT( stop() ) );
     connect( ui->pushButtonContinue, SIGNAL( clicked( bool ) ), timerRecord, SLOT( start() ) );
 
+    // Update
     ui->label_Upate_tab_1->clear();
     ui->label_Upate_tab_4->clear();
     connect( &version, SIGNAL( signal_newVersionAvailable( QString ) ), this, SLOT( slot_newVersionAvailable( QString ) ) );
     connect( ui->checkBoxLookForUpdates, SIGNAL( toggled( bool ) ), &version, SLOT( slot_doDownload( bool ) ) );
+
+    // Frames, Format, Codecs
+    connect( ui->comboBoxFormat,       SIGNAL( currentTextChanged( QString ) ), this, SLOT( slot_Format( QString ) ) );
+    connect( ui->comboBoxVideoCodec,   SIGNAL( currentTextChanged( QString ) ), this, SLOT( slot_Videocodec( QString ) ) );
+    connect( ui->comboBoxAudioCodec,   SIGNAL( currentTextChanged( QString ) ), this, SLOT( slot_Audiocodec( QString ) ) );
+    connect( mainWindow->sliderFrames, SIGNAL( valueChanged( int ) ),           this, SLOT( slot_Frames( int ) ) );
+
 }
 
 
@@ -75,6 +87,46 @@ QvkInformation::~QvkInformation()
 }
 
 
+void QvkInformation::slot_Format( QString value )
+{
+    ui->labelInfoFormat->setText( value );
+    ui->labelInfoFrames->setText( QString::number( mainWindow->sliderFrames->value() ) );
+}
+
+
+void QvkInformation::slot_Videocodec( QString value )
+{
+    ui->labelInfoVideocodec->setText( value );
+}
+
+
+void QvkInformation::slot_Audiocodec( QString value )
+{
+    bool bo = false;
+    QList<QCheckBox *> listCheckBox = ui->scrollAreaAudioDevice->findChildren<QCheckBox *>();
+    for ( int i = 0; i < listCheckBox.count(); i++ )
+    {
+        if ( listCheckBox.at(i)->checkState() == Qt::Checked )
+        {
+            bo = true;
+            break;
+        }
+    }
+
+    if ( bo == false ) {
+        ui->labelInfoAudiocodec->setText( "------" );
+    } else {
+        ui->labelInfoAudiocodec->setText( value );
+    }
+}
+
+
+void QvkInformation::slot_Frames( int value )
+{
+    ui->labelInfoFrames->setText( QString::number( value ) );
+}
+
+
 void QvkInformation::slot_newVersionAvailable( QString update )
 {
     if ( ui->checkBoxLookForUpdates->isChecked() == true )
@@ -82,12 +134,12 @@ void QvkInformation::slot_newVersionAvailable( QString update )
         if ( global::version < update )
         {
             QString string = "New Version available: " + update;
-            ui->label_Upate_tab_1->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>" + string + "</a>" );
-            ui->label_Upate_tab_4->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>" + string + "</a>" );
+            ui->label_Upate_tab_1->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen-download.html'>" + string + "</a>" );
+            ui->label_Upate_tab_4->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen-download.html'>" + string + "</a>" );
         }
         else
         {
-            ui->label_Upate_tab_4->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>No update available</a>" );
+            ui->label_Upate_tab_4->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen-download.html'>No update available</a>" );
         }
     }
     else
