@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs_CZ">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Přepnout na celou obrazovku</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Odpočítávání</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Nápověda</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nebyl nalezen žádný správce souborů.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím o instalaci správce souborů.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Prosím o instalaci správce souborů.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>Desktop session je relace Wayland</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Wayland zatím není podporován. Nahrávka ukazuje černou obrazovku. Odhlaste se a spusťte relaci plochy X11</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Zdrojový kód</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Podpořit</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Byla zjištěna relace plochy Wayland</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Otevřít soubor</translation>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno nebo více zařízení</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Odejít</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Zvětšení</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
