@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_MX">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Pasa a Pantalla Completa</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Cuenta regresiva</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Ayuda</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró el manejador de archivos.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor, instale un manejador de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Por favor, instale un manejador de archivos.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>La sesión del escritorio es una sesión Wayland</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>A la fecha, no se soporta el Wayland. La pantalla de grabación se ve negra. Por favor, cierre la sesión e inicie una sesión gráfica con X11.    </translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Código fuente</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Donar</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Se ha detectado una sesión gráfica Wayland </translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Abrir Archivo</translation>
+        <source>Select one or more devices</source>
+        <translation>Elige uno o más dispositivos</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Salir</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ampliación</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
