@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="eu_ES" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="eu_ES">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Aldatu pantaila osora</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Atzera-kontua</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Laguntza</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi arakatzaile bat.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Instalatu fitxategi arakatzaile bat.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>Mahaigaineko saioa Wayland saioa da</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Wayland oraindik ez da onartzen. Pantaila-grabazioak pantaila beltza erakusten du. Amaitu saioa eta hasi X11 mahaigaineko saioa</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Iturburu-kodea</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Eman dirua</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Wayland mahaigaineko saioa hauteman da</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Ireki fitxategia</translation>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>irten</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Lupa</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
