@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it_IT">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Modalità schermo intero</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Ritarda avvio</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Aiuto</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Filemanager non trovato</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Si prega di installare un filemanager</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Si prega di installare un filemanager</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>La sessione desktop é una sessione &quot;Wayland&quot;</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Al momento &quot;Wayland&quot; non é supportato. Lo screencast mostra una schermata nera. SI prega di eseguire un logout e avviare una sessione desktop X11</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Codice sorgente</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Fai una donazione</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Sessione &quot;Wayland&quot; rilevata</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Apri file</translation>
+        <source>Select one or more devices</source>
+        <translation>Seleziona uno o più dispositivi</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Esci</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Webcam</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ingrandimento</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
