@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja_JP">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>全画面表示</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>カウントダウン</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>ヘルプ</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>ファイルマネージャーが見つかりません</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>ファイルマネージャーをインストールしてください</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>ファイルマネージャーをインストールしてください</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>デスクトップセッションは、Waylandセッションです</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Waylandはサポートされていません。スクリーンキャストは、黒い画面を表示します。ログアウトしてX11デスクトップセッションを開始してください。</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>ソースコード</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>寄付</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Waylandデスクトップセッションを検出</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>ファイルを開く</translation>
+        <source>Select one or more devices</source>
+        <translation>一つ以上のデバイスを選択</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>終了する</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>カメラ</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>拡大</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
