@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Perjungti į visą ekraną</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Atvirkštinis skaičiavimas</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Žinynas</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nerasta jokios failų tvarkytuvės.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Įdiekite failų tvarkytuvę.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Įdiekite failų tvarkytuvę.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>Darbalaukio seansas yra Wayland seansas</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Šiuo metu Wayland nėra palaikomas. Ekrano įrašas rodys juodą ekraną. Atsijunkite ir paleiskite X11 darbalaukio seansą</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Pirminis kodas</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Paaukoti</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Aptiktas Wayland darbalaukio seansas</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Atverti failą</translation>
+        <source>Select one or more devices</source>
+        <translation>Pasirinkite vieną ar daugiau įrenginių</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Išeiti</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Didinimas</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
