@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl_NL">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Beeldvullende weergave</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Aftellen</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Hulp</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -53,7 +57,7 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>De opname is niet begonnen omdat er onvoldoende vrije schijfruimte is.</translation>
+        <translation>De opname kan niet worden gestart omdat er onvoldoende vrije schijfruimte is.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
@@ -84,20 +88,12 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Er is geen bestandsbeheerder gevonden.</translation>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
         <translation>Installeer een bestandsbeheerder.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>De bureaubladsessie is een Wayland-sessie</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Wayland wordt momenteel niet ondersteund - screencasts zullen een zwart scherm tonen. Log uit en start een X11-bureaubladsessie.</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Broncode</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Doneren</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Wayland-bureaubladsessie gedetecteerd</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Bestand openen</translation>
+        <source>Select one or more devices</source>
+        <translation>Selecteer één of meer apparaten</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Afsluiten</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Vergroting</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
@@ -286,7 +286,7 @@
     </message>
     <message>
         <source>Do not record mouse cursor</source>
-        <translation>Cursor niet vastleggen</translation>
+        <translation>Cursor verbergen</translation>
     </message>
     <message>
         <source>Hour</source>
