@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk_SK">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -17,18 +17,11 @@
     <name>QvkCameraWindow</name>
     <message>
         <source>Switch to Window</source>
-        <translation>Prepnutie na jedno okno</translation>
+        <translation>Zobraziť v okne</translation>
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Prepnutie na celú obrazovku</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Odpočítavanie</translation>
+        <translation>Zobraziť na celú obrazovku</translation>
     </message>
 </context>
 <context>
@@ -45,6 +38,17 @@
         <translation>Pomocník</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nenašiel sa žiadny súborový manažér.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Inštalujte súborový manažér.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -65,7 +69,7 @@
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>Megabyte</translation>
+        <translation>Megabajt</translation>
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
@@ -90,15 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Inštalujte súborový manažér.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>Desktopové sedenie je typu Wayland</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Momentálne Wayland nie je podporovaný. Namiesto nahrávky je čierna obrazovka.
-Odhláste sa a naštartujte X11 desktopové sedenie</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Zdrojový kód</translation>
@@ -115,16 +110,12 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
         <source>Donate</source>
         <translation>Podporiť</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Detekované Wayland desktopové sedenie</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Otvoriť súbor</translation>
+        <source>Select one or more devices</source>
+        <translation>Vyberte jedno alebo viac zariadení</translation>
     </message>
 </context>
 <context>
@@ -156,6 +147,14 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
         <source>Exit</source>
         <translation>Odísť</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Zväčšenie</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
@@ -200,7 +199,7 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>Stupne šedi</translation>
+        <translation>Stupne sivej</translation>
     </message>
     <message>
         <source>Black-and-white</source>
@@ -299,11 +298,11 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Start the timer</source>
-        <translation>Naštartovať stopky</translation>
+        <translation>Spustiť stopky</translation>
     </message>
     <message>
         <source>Stop recording after</source>
-        <translation>Stopnúť nahrávanie po</translation>
+        <translation>Zastaviť nahrávanie po</translation>
     </message>
     <message>
         <source>Hours</source>
@@ -327,7 +326,7 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Show in systray</source>
-        <translation>Zobraziť v systémovej lište</translation>
+        <translation>Zobraziť v systémovom paneli</translation>
     </message>
     <message>
         <source>Second wait before recording</source>
@@ -335,7 +334,7 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Look for updates</source>
-        <translation>Skontrolovať novšie verzie</translation>
+        <translation>Kontrola aktualizácií</translation>
     </message>
     <message>
         <source>Help</source>
@@ -387,11 +386,11 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>Stupne šedi</translation>
+        <translation>Stupne sivej</translation>
     </message>
     <message>
         <source>Send Report</source>
-        <translation>Poslať hlásenie</translation>
+        <translation>Odoslať hlásenie</translation>
     </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
@@ -423,7 +422,7 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Starts minimized</source>
-        <translation>Naštartovať minimalizované okno</translation>
+        <translation>Spustiť minimalizované</translation>
     </message>
     <message>
         <source>Flip horizontal</source>
@@ -451,11 +450,11 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Copyright a licencia z obrázkov</translation>
+        <translation>Copyright a licencie obrázkov</translation>
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>Megabyte</translation>
+        <translation>Megabajt</translation>
     </message>
     <message>
         <source>Screencast</source>
@@ -474,7 +473,7 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     <name>license</name>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Copyright a licencia z obrázkov</translation>
+        <translation>Copyright a licencie obrázkov</translation>
     </message>
 </context>
 <context>
@@ -501,15 +500,15 @@ Odhláste sa a naštartujte X11 desktopové sedenie</translation>
     </message>
     <message>
         <source>Previous frame</source>
-        <translation>Predchádzajúci snímok</translation>
+        <translation>Predchádzajúce políčko</translation>
     </message>
     <message>
         <source>Next frame</source>
-        <translation>Nasledujúci snímok</translation>
+        <translation>Nasledujúce políčko</translation>
     </message>
     <message>
         <source>Mute</source>
-        <translation>Umlčať</translation>
+        <translation>Stíšiť</translation>
     </message>
     <message>
         <source>Move menu</source>
