@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
 <context>
     <name>QvkAudioController</name>
     <message>
@@ -24,13 +24,6 @@
         <translation>Preklopi na celozaslonski način</translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation>Odštevalnik</translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -45,6 +38,17 @@
         <translation>Pomoč</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ni najdenega upravljalnika datotek.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Program za urejanje datotek je treba namestiti.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -90,14 +94,6 @@
         <source>Please install a filemanager.</source>
         <translation>Program za urejanje datotek je treba namestiti.</translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation>Namizna seja je seja Wayland</translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation>Merjenje časa v okolju Wayland ni podprto. Zaslonski posnetek pokaže črn zaslon. Odjavite se in  začnite namizno sejo X11.</translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation>Izvorna koda</translation>
@@ -114,16 +110,12 @@
         <source>Donate</source>
         <translation>Doniraj</translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation>Zaznana je namizna seja Wayland</translation>
-    </message>
 </context>
 <context>
-    <name>QvkPlayer</name>
+    <name>QvkPulseAudioWatcher</name>
     <message>
-        <source>Open File</source>
-        <translation>Odpri datoteko</translation>
+        <source>Select one or more devices</source>
+        <translation>Izbor ene ali več naprav</translation>
     </message>
 </context>
 <context>
@@ -155,6 +147,14 @@
         <source>Exit</source>
         <translation>Končaj</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Povečava</translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
