@@ -32,14 +32,23 @@
 #include "QvkSystray.h"
 #include "QvkMagnifierController.h"
 #include "QvkPlayer.h"
-#include "QvkTheme.h"
 #include "QvkLimitDiskFreeSpace.h"
 #include "QvkSpezialSlider.h"
 #include "QvkSystrayAlternative.h"
 #include "QvkAudioController.h"
+#include "QvkShowClick.h"
+#include "QvkHalo.h"
+#include "QvkGlobalShortcut.h"
+
+#ifdef Q_OS_WIN
+  #include "QvkCiscoOpenh264Controller.h"
+#endif
+
 #include <QMainWindow>
 #include <QFileSystemWatcher>
 #include <QSoundEffect>
+#include <QShowEvent>
+//#include <QWindow>
 
 #include <gst/gst.h>
 
@@ -61,13 +70,18 @@ public:
     QvkHelp *vkHelp;
     QvkSystray *vkSystray;
     QvkAudioController *vkAudioController;
+    QvkSpezialSlider *sliderFrames;
+
+    QvkMagnifierController *vkMagnifierController;
+    QvkGlobalShortcut *vkGlobalShortcut;
 
 private:
+    QvkShowClick *vkShowClick;
+
     QvkSpezialSlider *sliderScreencastCountDown;
-    QvkSpezialSlider *sliderFrames;
     QvkSpezialSlider *sliderX264;
     QvkSpezialSlider *sliderOpenh264;
-    QvkSpezialSlider *sliderVaapih264;
+    QvkSpezialSlider *sliderVp8;
     QvkSpezialSlider *sliderLimitOfFreeDiskSpace;
     QvkSpezialSlider *sliderShowInSystrayAlternative;
     QvkSpezialSlider *sliderHour;
@@ -78,7 +92,6 @@ private:
     QvkSpezialSlider *sliderStopRecordingAfterSeconds;
 
     QvkSettings vkSettings;
-    QStringList resolutionStringList;
 
     const QString VK_Gstr_Pipe = " ! ";
     QString VK_GStreamer_Version();
@@ -94,7 +107,6 @@ private:
     GError *error = Q_NULLPTR;
 
     QStringList videoFormatsList;
-    QStringList globalFormatsList;
 
     void VK_Supported_Formats_And_Codecs();
     void VK_Check_is_Format_available();
@@ -108,7 +120,6 @@ private:
     QString get_width_From_Screen();
     QString get_height_From_Screen();
 
-    void VK_gst_formatVideoAudoicodec_available();
     void VK_gst_Elements_available();
 
     QTimer *timerStartTimer;
@@ -117,8 +128,7 @@ private:
     void vk_setCornerWidget( QTabWidget *tabWidget );
 
     QvkPlayer *vkPlayer;
-
-    QvkTheme *vkTheme;
+    QvkHalo *vkHalo;
 
     QvkCameraController *vkCameraController;
     QvkSystrayAlternative *vkSystrayAlternative;
@@ -132,12 +142,18 @@ private:
 
     QString Pipeline_structured_output( QString pipeline );
 
-    bool onlyOnce = false;
-
     QSoundEffect *soundEffect;
 
+    bool cancel = false;
+
+#ifdef Q_OS_WIN
+    QvkCiscoOpenh264Controller *vkCiscoOpenh264Controller;
+#endif
+
 
 private slots:
+    void slot_textToGuiLog( QString value );
+
     void slot_preStart();
     void slot_Start();
     void slot_preStop();
@@ -148,7 +164,6 @@ private slots:
     void slot_Folder();
     void slot_screenCountChanged( QString, QString );
     void slot_screenCountChangedArea( QString stringText, QString stringData );
-//    void slot_audioIconOnOff(bool state );
     void slot_newVideoPath();
     void slot_videoFileSystemWatcherSetButtons();
     void slot_videoFileSystemWatcherSetNewPath();
@@ -161,14 +176,11 @@ private slots:
     void slot_framesReset();
     void slot_x264Reset();
     void slot_openh264Reset();
-    void slot_Vaapih264Reset();
+    void slot_vp8Reset();
 
     void slot_StartTimer( bool value );
     void slot_startTime();
     void slot_areaSetResolution( QString value );
-    void slot_areaReset();
-    void slot_disableAreaWidgets();
-    void slot_enableAreaWidgets();
 
     void slot_IfStartAudioCodecWidgetsSetEnabled();
     void slot_IfStopAudioCodecWidgetsSetDisabled();
@@ -179,9 +191,13 @@ private slots:
 
     void slot_vokoPlayer();
 
-#ifdef Q_OS_LINUX
-    void slot_afterWindowShown();
-#endif
+    void slot_setMaxFPS( int );
+
+    void slot_gst_formatVideoAudoicodec_available();
+
+    void slot_cancel( bool value );
+
+    void slot_haveAudioDeviceSelected( bool bo );
 
 
 signals:
@@ -194,9 +210,6 @@ signals:
 protected:
     void closeEvent( QCloseEvent *event );
     void resizeEvent( QResizeEvent *event );
-#ifdef Q_OS_LINUX
-    void showEvent( QShowEvent *event );
-#endif
 
 
 };
