@@ -24,6 +24,7 @@
 #include "QvkPlayerVideoSurface.h"
 #include "QvkSpezialSlider.h"
 #include "global.h"
+#include "QvkFileDialog.h"
 
 #include <QTime>
 #include <QStandardPaths>
@@ -77,14 +78,14 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
 
     ui->framePlayer->setStyleSheet( "QFrame { background-color: black; }" );
 
-    ui->pushButtonPlay->setIcon( QIcon::fromTheme( "media-playback-start" , style()->standardIcon( QStyle::SP_MediaPlay ) ) );
-    ui->pushButtonPause->setIcon( QIcon::fromTheme( "media-playback-pause", style()->standardIcon( QStyle::SP_MediaPause ) ) );
-    ui->pushButtonStop->setIcon( QIcon::fromTheme( "media-playback-stop"  , style()->standardIcon( QStyle::SP_MediaStop ) ) );
-    ui->toolButtonFrameBackward->setIcon( QIcon::fromTheme( "go-previous",  style()->standardIcon( QStyle::SP_MediaSeekBackward ) ) );
-    ui->toolButtonFrameForward->setIcon( QIcon::fromTheme( "go-next",       style()->standardIcon( QStyle::SP_MediaSeekForward ) ) );
-    ui->toolButtonOpenFile->setIcon( QIcon::fromTheme( "document-open",     style()->standardIcon( QStyle::SP_FileIcon ) ) );
-    ui->toolButtonMute->setIcon( QIcon::fromTheme( "audio-volume-high"    , style()->standardIcon( QStyle::SP_MediaVolume ) ) );
-    ui->toolButtonFullscreen->setIcon( QIcon::fromTheme( "view-fullscreen", QIcon( ":/pictures/player/fullscreen.png" ) ) );
+    ui->pushButtonPlay->setIcon( QIcon (":/pictures/player/start.png" ) );
+    ui->pushButtonPause->setIcon(QIcon( ":/pictures/player/pause.png" ) );
+    ui->pushButtonStop->setIcon( QIcon( ":/pictures/player/stop.png" ) );
+    ui->toolButtonFrameBackward->setIcon( QIcon( ":/pictures/player/go-previous.png" ) );
+    ui->toolButtonFrameForward->setIcon( QIcon( ":/pictures/player/go-next.png" ) );
+    ui->toolButtonOpenFile->setIcon( QIcon( ":/pictures/player/document-open.png" ) );
+    ui->toolButtonMute->setIcon( QIcon( ":/pictures/player/audio-volume-high.png" ) );
+    ui->toolButtonFullscreen->setIcon( QIcon( ":/pictures/player/fullscreen.png" ) );
 
     mediaPlayer = new QMediaPlayer;
     sliderVolume->setValue( 70 );
@@ -100,7 +101,7 @@ QvkPlayer::QvkPlayer( QMainWindow *parent, Ui_formMainWindow *ui_mainwindow ) :
     connect( mediaPlayer, SIGNAL( positionChanged( qint64 ) ),           this, SLOT( slot_positionChanged( qint64 ) ) );
     connect( mediaPlayer, SIGNAL( stateChanged( QMediaPlayer::State ) ), this, SLOT( slot_stateChanged( QMediaPlayer::State ) ) );
     connect( mediaPlayer, SIGNAL( volumeChanged( int ) ),                this, SLOT( slot_volumeChanged( int ) ) ); // Funktioniert nicht mit Pulse
-    connect( mediaPlayer, QOverload<QMediaPlayer::Error>::of(&QMediaPlayer::error), [=](QMediaPlayer::Error error)
+    connect( mediaPlayer, QOverload<QMediaPlayer::Error>::of(&QMediaPlayer::error), this, [=](QMediaPlayer::Error error)
     {
         switch ( error )
         {
@@ -329,23 +330,26 @@ void QvkPlayer::setMediaFile( QString string )
 
 void QvkPlayer::slot_openFile()
 {
-    if ( pathOpenFile == "" )
+    QApplication::setDesktopSettingsAware( false );
+
+    QString file;
+    QvkFileDialog vkFileDialog( this );
+    vkFileDialog.setVideoPath( uiMainWindow->lineEditVideoPath->text() );
+    if ( vkFileDialog.exec() == QDialog::Accepted )
     {
-        pathOpenFile = QStandardPaths::writableLocation( QStandardPaths::MoviesLocation );
+        if ( !vkFileDialog.selectedFiles().empty() ) {
+            file = vkFileDialog.selectedFiles().at(0);
+        }
     }
 
-
-    QString file = QFileDialog::getOpenFileName( this,
-                                                 tr( "Open File" ),
-                                                 pathOpenFile,
-                                                 "" );
-
     if ( !file.isEmpty() )
     {
         setMediaFile( file );
         slot_play();
         pathOpenFile = QDir( file ).absolutePath();
     }
+
+    QApplication::setDesktopSettingsAware( true );
 }
 
 
@@ -401,7 +405,7 @@ void QvkPlayer::slot_play()
 {
     show();
     mediaPlayer->play();
-    parentMainWindow->setWindowTitle( mediaPlayer->currentMedia().canonicalUrl().fileName() + " - " + oldWindowTitel );
+    parentMainWindow->setWindowTitle( mediaPlayer->currentMedia().request().url().toString() + " - " + oldWindowTitel );
 }
 
 
@@ -427,7 +431,7 @@ void QvkPlayer::slot_mutedChanged( bool muted )
 {
     if ( muted == true )
     {
-        ui->toolButtonMute->setIcon( QIcon::fromTheme( "audio-volume-muted", style()->standardIcon( QStyle::SP_MediaVolumeMuted ) ) );
+        ui->toolButtonMute->setIcon( QIcon( ":/pictures/player/audio-volume-muted.png" ) );
         sliderVolume->setEnabled( false );
         ui->toolButtonMute->setEnabled( true );
         return;
@@ -435,7 +439,7 @@ void QvkPlayer::slot_mutedChanged( bool muted )
 
     if ( muted == false )
     {
-        ui->toolButtonMute->setIcon( QIcon::fromTheme( "audio-volume-high", style()->standardIcon( QStyle::SP_MediaVolume ) ) );
+        ui->toolButtonMute->setIcon( QIcon( ":/pictures/player/audio-volume-high.png" ) );
         sliderVolume->setEnabled( true );
         ui->toolButtonMute->setEnabled( true );
         return;
@@ -622,14 +626,16 @@ QSize QvkPlayer::getPixelaspectRatio()
 void QvkPlayer::vk_showFullscreen()
 {
     uiMainWindow->tabWidgetSideBar->hide();
-    uiMainWindow->verticalLayoutCentralWidget->addWidget( this );
+    uiMainWindow->widgetSidbar->hide();
+    uiMainWindow->horizontalLayout_49->addWidget( this );
+
     parentMainWindow->showFullScreen();
 
     ui->widgetMenueBar->setParent( ui->labelPlayer);
     ui->framePlayer->setStyleSheet( "QFrame { background-color: black; }"  );
     ui->widgetMenueBar->setStyleSheet( "QWidget { background-color: lightgray; }" );
     ui->labelMovePicture->setStyleSheet( "QLabel { background-color: lightgray; }" );
-    ui->toolButtonFullscreen->setIcon( QIcon::fromTheme( "view-restore", QIcon( ":/pictures/player/restore.png" ) ) );
+    ui->toolButtonFullscreen->setIcon( QIcon( ":/pictures/player/restore.png" ) );
     ui->labelMovePicture->show();
     ui->widgetMenueBar->show();
     ui->labelPlayer->setFocus();
@@ -647,6 +653,7 @@ void QvkPlayer::vk_showFullscreen()
 void QvkPlayer::vk_showNormal()
 {
     uiMainWindow->tabWidgetSideBar->show();
+    uiMainWindow->widgetSidbar->show();
     uiMainWindow->verticalLayoutTabSidebarPlayer->addWidget( this );
     parentMainWindow->showNormal();
 
@@ -654,7 +661,7 @@ void QvkPlayer::vk_showNormal()
     ui->framePlayer->setStyleSheet( "QFrame { background-color: black; }"  );
     // An empty string resets the color
     ui->widgetMenueBar->setStyleSheet( "" );
-    ui->toolButtonFullscreen->setIcon( QIcon::fromTheme( "view-fullscreen", QIcon( ":/pictures/player/fullscreen.png" ) ) );
+    ui->toolButtonFullscreen->setIcon( QIcon( ":/pictures/player/fullscreen.png" ) );
     ui->labelMovePicture->hide();
     ui->widgetMenueBar->show();
     ui->labelPlayer->setFocus();
