@@ -40,7 +40,7 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
                                    HandleColorBackground( Qt::lightGray ),
                                    HandleColorBackgroundSize( Qt::lightGray ),
                                    HandleColorByMousePressed( Qt::lightGray ),
-                                   colorSelectedArrow( Qt::darkYellow ),
+                                   colorSelectedArrow( Qt::green ),
                                    framePenWidth(4), // framePenWidth must be an even number
                                    framePenHalf(framePenWidth/2),
                                    radius(20),
@@ -71,7 +71,7 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
     setWindowIcon( icon );
 
     // Hint: Qt::WindowStaysOnTopHint is only for X11 and Windows on WayLand not do it
-    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint );
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint ); // With Qt::ToolTip no keyboard;
     setAttribute( Qt::WA_TranslucentBackground, true);
     setMouseTracking( true );
     setFrameColor( Qt::darkGreen );
@@ -966,7 +966,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     QRect regionTopLeft( frame_X - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
     if ( regionTopLeft.contains( event->pos() ) )
     {
-        setCursor( Qt::SizeFDiagCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_fdiag.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = TopLeft;
         return;
     }
@@ -974,7 +976,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     QRect regionTopMiddle( frame_X + frame_Width/2 - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
     if ( regionTopMiddle.contains( event->pos() )  )
     {
-        setCursor( Qt::SizeVerCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_ver.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = TopMiddle;
         return;
     }
@@ -982,7 +986,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     QRect regionTopRight( frame_X + frame_Width - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
     if ( regionTopRight.contains( event->pos() )  )
     {
-        setCursor( Qt::SizeBDiagCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_bdiag.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = TopRight;
         return;
     }
@@ -990,15 +996,19 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     QRect regionRightMiddle( frame_X + frame_Width - radius - 1, frame_Y + frame_height/2 - radius - 1, diameter + 2, diameter + 2 );
     if ( regionRightMiddle.contains( event->pos() )  )
     {
+        QPixmap pixmap( ":/pictures/cursor/size_hor.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = RightMiddle;
-        setCursor( Qt::SizeHorCursor );
         return;
     }
 
     QRect regionMiddle( frame_X + frame_Width/2 - radius - penHalf, frame_Y + frame_height/2 - radius - penHalf, 2 * radius + penWidth, 2 * radius + penWidth);
     if ( regionMiddle.contains( event->pos() )  )
     {
-        setCursor( Qt::SizeAllCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_all.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = Middle;
         return;
     }
@@ -1011,7 +1021,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                               );
     if( regionBottomRight.contains( event->pos()) )
     {
-        setCursor(  Qt::SizeFDiagCursor);
+        QPixmap pixmap( ":/pictures/cursor/size_fdiag.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = BottomRight;
         return;
     }
@@ -1023,7 +1035,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                                );
     if( regionBottomMiddle.contains( event->pos()) )
     {
-        setCursor( Qt::SizeVerCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_ver.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = BottomMiddle;
         return;
     }
@@ -1035,7 +1049,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                             );
     if( regionBottomLeft.contains( event->pos()) )
     {
-        setCursor( Qt::SizeBDiagCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_bdiag.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = BottomLeft;
         return;
     }
@@ -1047,7 +1063,9 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                             );
     if( regionLeftMiddle.contains( event->pos()) )
     {
-        setCursor( Qt::SizeHorCursor );
+        QPixmap pixmap( ":/pictures/cursor/size_hor.png" );
+        QCursor cursor( pixmap );
+        setCursor( cursor );
         handleUnderMouse = LeftMiddle;
         return;
     }
@@ -1068,7 +1086,7 @@ void QvkRegionChoise::printSize( QPainter &painter )
   painter.setFont( font );
 
   QFontMetrics fontMetrics( font );
-  pixelWidth = fontMetrics.width( widthHeigtSize );
+  pixelWidth = fontMetrics.horizontalAdvance( widthHeigtSize );
   pixelHeight = fontMetrics.height();
   QRect rect( frame_X + frame_Width/2 - pixelWidth/2 - 5,
               frame_Y + frame_height/2 - pixelHeight/2 - 50,
@@ -1170,7 +1188,7 @@ void QvkRegionChoise::HandleTopLeftSize( QPainter &painter)
     string.append( "x:" + QString::number( frame_X ) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height() * 2;
     QRect rect( frame_X + radius,
                 frame_Y + radius,
@@ -1227,7 +1245,7 @@ void QvkRegionChoise::HandleTopMiddleSize( QPainter &painter )
     string.append( "  " );
     string.append( "y:" + QString::number( frame_Y ) );
     string.append( "  " );
-    pixelWidth = fontMetrics.width( string);
+    pixelWidth = fontMetrics.horizontalAdvance( string);
     pixelHeight = fontMetrics.height();
     QRect rect( frame_X + frame_Width/2 - pixelWidth/2,
                 frame_Y + radius + 5,
@@ -1282,7 +1300,7 @@ void QvkRegionChoise::HandleTopRightSize( QPainter &painter )
     string.append( "x:" + QString::number( frame_X + frame_Width - framePenHalf ) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height() * 2;
     QRect rect( frame_X + frame_Width - pixelWidth - radius,
                 frame_Y + radius,
@@ -1339,7 +1357,7 @@ void QvkRegionChoise::HandleRightMiddleSize( QPainter &painter )
     string.append( "x:" + QString::number( frame_X + frame_Width - framePenHalf ) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height();
     QRect rect( frame_X + frame_Width - pixelWidth - radius - 5,
                 frame_Y + frame_height/2 - pixelHeight/2,
@@ -1395,7 +1413,7 @@ void QvkRegionChoise::HandleBottomRightSize( QPainter &painter )
     string.append( "x:" + QString::number( frame_X + frame_Width - framePenHalf) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height() * 2;
     QRect rect( frame_X + frame_Width - pixelWidth - radius,
                 frame_Y + frame_height - pixelHeight - radius,
@@ -1453,7 +1471,7 @@ void QvkRegionChoise::HandleBottomMiddleSize(QPainter &painter )
     string.append( "  " );
     string.append( "y:" + QString::number( frame_Y ) );
     string.append( "  " );
-    pixelWidth = fontMetrics.width( string);
+    pixelWidth = fontMetrics.horizontalAdvance( string);
     pixelHeight = fontMetrics.height();
     QRect rect( frame_X + frame_Width/2 - pixelWidth/2,
                 frame_Y + frame_height - pixelHeight - radius - 5,
@@ -1508,7 +1526,7 @@ void QvkRegionChoise::HandleBottomLeftSize( QPainter &painter )
     string.append( "x:" + QString::number( frame_X ) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height() * 2;
     QRect rect( frame_X + radius,
                 frame_Y + frame_height - pixelHeight - radius - 5,
@@ -1565,7 +1583,7 @@ void QvkRegionChoise::HandleLeftMiddleSize( QPainter &painter )
     string.append( "x:" + QString::number( frame_X ) );
     string.append( "  ");
     QFontMetrics fontMetrics( font );
-    pixelWidth = fontMetrics.width( string );
+    pixelWidth = fontMetrics.horizontalAdvance( string );
     pixelHeight = fontMetrics.height();
     QRect rect( frame_X + radius + 5,
                 frame_Y + frame_height/2 - pixelHeight/2,
