@@ -23,11 +23,12 @@
 #ifndef QVKSETTINGS_H 
 #define QVKSETTINGS_H
 
-#include "ui_formMainWindow.h"
 #include "QvkRegionChoise.h"
 #include "QvkCameraController.h"
 #include "QvkSystrayAlternative.h"
 #include "QvkPlayer.h"
+#include "QvkHalo.h"
+#include "QvkShowClick.h"
 
 #include <QObject>
 #include <QSettings>
@@ -40,21 +41,32 @@ class QvkSettings: public QObject
 public:
     QvkSettings();
     virtual ~QvkSettings();
-    void saveAll(Ui_formMainWindow *ui_mainwindow, QMainWindow *parent, bool log);
-    void readAll(Ui_formMainWindow *ui_mainwindow, QMainWindow *parent);
-    void saveAreaScreencast(qreal x, qreal y, qreal width, qreal height);
-    void readAreaScreencast(QvkRegionChoise *vkRegionChoise);
+
+    void saveAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent, bool log );
+    void readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent );
+
+    void saveAreaScreencast( qreal x, qreal y, qreal width, qreal height );
+    void readAreaScreencast( QvkRegionChoise *vkRegionChoise );
+
     void saveCamera( int x, int y );
     void readCamera( QvkCameraController *vkCameraController );
+
     void saveSystrayAlternative( int x, int y );
     void readSystrayAlternative( QvkSystrayAlternative *vkSystrayAlternative );
-    void savePlayerPathOpenFile(QString pathFile );
-    void readPlayerPathOpenFile(QvkPlayer *vkplayer);
+
+    void savePlayerPathOpenFile( QString pathFile );
+    void readPlayerPathOpenFile( QvkPlayer *vkplayer );
+
+    void saveHaloColor( QColor color );
+    void readHaloColor( QvkHalo *vkHalo );
+
+    void saveShowclickColor( QColor color );
+    void readShowclickColor( QvkShowClick *vkShowClick );
+
     QString getFileName();
     QString getVideoPath();
 
 
-
 public slots:
 
 
