@@ -26,13 +26,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>QvkCountdown</name>
-    <message>
-        <source>Countdown</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -47,6 +40,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -92,14 +96,6 @@
         <source>Please install a filemanager.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Desktop session is a Wayland session</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Sourcecode</source>
         <translation type="unfinished"></translation>
@@ -116,17 +112,6 @@
         <source>Donate</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Wayland desktop session detected</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>QvkPlayer</name>
-    <message>
-        <source>Open File</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -164,6 +149,14 @@
         <source>Exit</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QvkSystrayAlternative</name>
